@@ -1,9 +1,5 @@
 import threading
 
-import redis
-
-from django.conf import settings
-
 from . import util
 
 class LonglivingThread(threading.Thread):
@@ -12,8 +8,6 @@ class LonglivingThread(threading.Thread):
     def __init__(self, bail):
         self._bail = bail
         super(LonglivingThread, self).__init__()
-    def get_redis_client(self):
-        return redis.client.Redis(**settings.REDIS_PARAMS)
     def watch_queue(self, client, name, unpack=False):
         while not self._bail.isSet():
             result = client.blpop(name, 2)
@@ -25,5 +19,6 @@ class LonglivingThread(threading.Thread):
 
             yield key, item
 
+    get_redis_client = staticmethod(util.get_redis_client)
     pack = staticmethod(util.pack)
     unpack = staticmethod(util.unpack)
